diff src/vim9.h @ 19558:8eeec8886c02 v8.2.0336

patch 8.2.0336: Vim9: insufficient test coverage for compiling Commit: https://github.com/vim/vim/commit/42a480bf7243ea8bce498264911e187931d083e5 Author: Bram Moolenaar <Bram@vim.org> Date: Sat Feb 29 23:23:47 2020 +0100 patch 8.2.0336: Vim9: insufficient test coverage for compiling Problem: Vim9: insufficient test coverage for compiling. Solution: Add more tests.
author Bram Moolenaar <Bram@vim.org>
date Sat, 29 Feb 2020 23:30:04 +0100
parents 3b026343f398
children ec1eeb1b69e2
line wrap: on
line diff
--- a/src/vim9.h
+++ b/src/vim9.h
@@ -39,14 +39,18 @@ typedef enum {
     ISN_STORENR,    // store number into local variable isn_arg.storenr.str_idx
 
     // constants
-    ISN_PUSHNR,	    // push number isn_arg.number
-    ISN_PUSHBOOL,   // push bool value isn_arg.number
-    ISN_PUSHSPEC,   // push special value isn_arg.number
-    ISN_PUSHF,	    // push float isn_arg.fnumber
-    ISN_PUSHS,	    // push string isn_arg.string
-    ISN_PUSHBLOB,   // push blob isn_arg.blob
-    ISN_NEWLIST,    // push list from stack items, size is isn_arg.number
-    ISN_NEWDICT,    // push dict from stack items, size is isn_arg.number
+    ISN_PUSHNR,		// push number isn_arg.number
+    ISN_PUSHBOOL,	// push bool value isn_arg.number
+    ISN_PUSHSPEC,	// push special value isn_arg.number
+    ISN_PUSHF,		// push float isn_arg.fnumber
+    ISN_PUSHS,		// push string isn_arg.string
+    ISN_PUSHBLOB,	// push blob isn_arg.blob
+    ISN_PUSHFUNC,	// push func isn_arg.string
+    ISN_PUSHPARTIAL,	// push partial ?
+    ISN_PUSHCHANNEL,	// push channel isn_arg.channel
+    ISN_PUSHJOB,	// push channel isn_arg.job
+    ISN_NEWLIST,	// push list from stack items, size is isn_arg.number
+    ISN_NEWDICT,	// push dict from stack items, size is isn_arg.number
 
     // function call
     ISN_BCALL,	    // call builtin function isn_arg.bfunc
@@ -209,6 +213,8 @@ typedef struct {
 #ifdef FEAT_FLOAT
 	float_T		    fnumber;
 #endif
+	channel_T	    *channel;
+	job_T		    *job;
 	jump_T		    jump;
 	forloop_T	    forloop;
 	try_T		    try;